@@ -46,9 +46,7 @@ mkdir "$1"
 cd "$1"
 
 echo "this is the content of a plain file" > plain_file.txt
-if [ -x `which chattr` ] ; then
-   chattr +cdS plain_file.txt
-fi
+chattr +cdS plain_file.txt 2> /dev/null || true
 setfattr -n user.coucou -v hello plain_file.txt
 
 mkdir "$SUB1"
