@@ -266,7 +266,9 @@ listing:
 
 testing:
 
-diffing:
+diff:
+--fsa-scope none
+# because of birth date change when comparing with restored data
 
 EOF
 
