@@ -603,6 +603,11 @@ static S_I little_main(shared_ptr<user_interaction> & dialog, S_I argc, char * c
 		    repair_options.set_slice_min_digits(param.num_digits);
 		    repair_options.set_multi_threaded_crypto(param.multi_threaded_crypto);
 		    repair_options.set_multi_threaded_compress(param.multi_threaded_compress);
+		    if(param.iteration_count > 0)
+			repair_options.set_iteration_count(param.iteration_count);
+		    if(param.kdf_hash != hash_algo::none)
+			repair_options.set_kdf_hash(param.kdf_hash);
+
 		    if(repo)
 			repair_options.set_entrepot(repo);
 
