@@ -154,7 +154,7 @@ namespace libdar
 	    /// defines the protocol to use to retrieve slices
 	void set_entrepot(const std::shared_ptr<entrepot> & entr) { if(!entr) throw Erange("archive_options_read::set_entrepot", "null entrepot pointer given in argument"); x_entrepot = entr; };
 
-	    /// whether to warn (true) or ignore (false) signature failure (default is true)
+	    /// whether to warn (false) or ignore (true) signature failure (default is false, signature failure is reported)
 	void set_ignore_signature_check_failure(bool val) { x_ignore_signature_check_failure = val; };
 
 	    /// whether libdar is allowed to create several thread to work possibly faster on multicore CPU (need libthreadar to be effective)
@@ -368,7 +368,7 @@ namespace libdar
 	    /// compression is performed without block in one single stream per file.
 	    /// This is the historical way used by libdar, it gives the best result
 	    /// and the lowest compute overhead, though it cannot be parallelized.
-	    /// At the opposite using compresion per block reduce the compression ratio
+	    /// At the opposite using compression per block reduce the compression ratio
 	    /// but allows the block to be compressed/decompressed in parallel and thus
 	    /// leverage multi-core systems. When the block size increase you tend to the
 	    /// same compression ratio as compression ration without block
@@ -1914,6 +1914,13 @@ namespace libdar
 	    /// how much thread libdar will use for compression (need libthreadar too and compression_block_size > 0)
 	void set_multi_threaded_compress(U_I num) { x_multi_threaded_compress = num; };
 
+		    /// key derivation
+	void set_iteration_count(const infinint & val) { x_iteration_count = val; };
+
+	    /// hash algo used for key derivation
+	void set_kdf_hash(hash_algo algo) { x_kdf_hash = algo; };
+
+
 
 	    /////////////////////////////////////////////////////////////////////
 	    // getting methods
@@ -1944,6 +1951,9 @@ namespace libdar
 	const std::shared_ptr<entrepot> & get_entrepot() const { return x_entrepot; };
 	U_I get_multi_threaded_crypto() const { return x_multi_threaded_crypto; };
 	U_I get_multi_threaded_compress() const { return x_multi_threaded_compress; };
+	const infinint & get_iteration_count() const { return x_iteration_count; };
+	hash_algo get_kdf_hash() const { return x_kdf_hash; };
+
 
     private:
 	bool x_allow_over;
@@ -1972,6 +1982,8 @@ namespace libdar
 	std::shared_ptr<entrepot> x_entrepot;
 	U_I x_multi_threaded_crypto;
 	U_I x_multi_threaded_compress;
+	infinint x_iteration_count;
+	hash_algo x_kdf_hash;
 
 	void nullifyptr() noexcept {};
 	void copy_from(const archive_options_repair & ref);
