@@ -51,6 +51,7 @@ namespace libdar
 						  end_data_mode(false),
 						  sub_is_dying(false),
 						  sync_write_asked(false),
+						  weof(false),
 						  ehandle(handle),
 						  metadatamode(false),
 						  current_offset(0),
@@ -131,7 +132,7 @@ namespace libdar
 
     infinint fichier_libcurl::get_size() const
     {
-	double filesize;
+	curl_off_t filesize;
 	fichier_libcurl *me = const_cast<fichier_libcurl *>(this);
 
 	if(me == nullptr)
@@ -146,10 +147,10 @@ namespace libdar
 		try
 		{
 		    me->ehandle->apply(get_pointer(), wait_delay);
-		    me->ehandle->getinfo(CURLINFO_CONTENT_LENGTH_DOWNLOAD, &filesize);
+		    me->ehandle->getinfo(CURLINFO_CONTENT_LENGTH_DOWNLOAD_T, &filesize);
 		    if(filesize == -1) // file does not exist (or filesize is not known)
 			filesize = 0;
-		    me->maxpos = tools_double2infinint(filesize);
+		    me->maxpos = infinint(filesize);
 		    me->has_maxpos = true;
 		}
 		catch(...)
@@ -161,7 +162,7 @@ namespace libdar
 	    }
 	    catch(Egeneric & e)
 	    {
-		e.prepend_message("Error while reading file size on a remote repository");
+		e.prepend_message("Error while reading file size on a remote repository: ");
 		throw;
 	    }
 	}
@@ -506,6 +507,7 @@ namespace libdar
     void fichier_libcurl::initialize_subthread()
     {
 	sub_is_dying = false;
+	weof = false;
 	synchronize.wait(); // release calling thread as we, as child thread, do now exist
     }
 
@@ -797,10 +799,30 @@ namespace libdar
 	if(me == nullptr)
 	    throw SRC_BUG;
 
+	bool fetch_block = !me->weof || me->sync_write_asked;
+	    // with libcurl 7.74.0 and below, returning zero
+	    // bytes was properly addressed by libcurl as an EOF
+	    // and no more call to read_data_callback was "performed".
+	    // But with libcurl 7.88.1 read_data_callback() was called
+	    // again at least once after that, which lead fichier_libcurl
+	    // main thread hanging forever for curl_perform to end
+	    // because read_data_callback() was pending to receive
+	    // data from interthread pipe. To avoid that having the ending
+	    // of the subthread involving external software (libcurl) which
+	    // somehow changed without notice nor documentation change, we
+	    // add the weof boolean variable to avoid fetching from interthread
+	    // in that context.
+
 	do
 	{
 	    just_synced = false;
-	    me->interthread.fetch(ptr, ptr_size);
+	    if(fetch_block)
+		me->interthread.fetch(ptr, ptr_size);
+	    else // emulate an the fetching of a zero length block
+	    {
+		ptr_size = 0;
+		ptr = bufptr; // we will copy 0 bytes from bufptr to bufptr
+	    }
 
 		// note: if ptr_size is zero
 		// libcurl will assume EOF and stop
@@ -809,7 +831,8 @@ namespace libdar
 	    if(me->sync_write_asked && ptr_size == 0)
 	    {
 		me->sync_write_asked = false;
-		me->interthread.fetch_recycle(ptr);
+		if(fetch_block)
+		    me->interthread.fetch_recycle(ptr);
 		me->synchronize.wait();
 		just_synced = true;
 	    }
@@ -819,7 +842,8 @@ namespace libdar
 	if(ptr_size <= room)
 	{
 	    memcpy(bufptr, ptr, ptr_size);
-	    me->interthread.fetch_recycle(ptr);
+	    if(fetch_block)
+		me->interthread.fetch_recycle(ptr);
 	    ret = ptr_size;
 	}
 	else
@@ -827,10 +851,14 @@ namespace libdar
 	    memcpy(bufptr, ptr, room);
 	    ptr_size -= room;
 	    memmove(ptr, ptr + room, ptr_size);
-	    me->interthread.fetch_push_back(ptr, ptr_size);
+	    if(fetch_block)
+		me->interthread.fetch_push_back(ptr, ptr_size);
 	    ret = room;
 	}
 
+	if(fetch_block && ptr_size == 0 && !(me->sync_write_asked))
+	    me->weof = true;
+
 	return ret;
     }
 
