@@ -778,11 +778,13 @@ namespace libdar
 				  const path & chem_dst,
 				  const string & basename_dst,
 				  const string & extension_dst,
-				  const archive_options_repair & options_repair): mem_ui(dialog)
+				  const archive_options_repair & options_repair,
+				  statistics* progressive_report): mem_ui(dialog)
     {
+	statistics st = false;
+	statistics* st_ptr = progressive_report == nullptr ? &st : progressive_report;
 	archive_options_read my_options_read = options_read;
 	bool initial_pause = (*options_read.get_entrepot() == *options_repair.get_entrepot() && chem_src == chem_dst);
-	statistics not_filled;
 
 	    ////
 	    // initializing object fields
@@ -903,10 +905,10 @@ namespace libdar
 			     false,               // zeroing_neg_date
 			     set<string>(),       // ignored_symlinks
 			     modified_data_detection::any_inode_change, // not used for repairing
-			     src.pimpl->ver.get_iteration_count(),
-			     src.pimpl->ver.get_kdf_hash(),
+			     options_repair.get_iteration_count(),
+			     options_repair.get_kdf_hash(),
 			     delta_sig_block_size(), // sig block size is not used for repairing, build_delta_sig is set to false above
-			     &not_filled);        // statistics
+			     st_ptr);             // statistics
 
 		// stealing src's catalogue, our's is still empty at this step
 	    catalogue *tmp = cat;
@@ -1164,11 +1166,8 @@ namespace libdar
 		    first_slice_size = last_slice_size;
 		    archive_size = last_slice_size;
 		}
-
-		if(slice_number > 1)
-		    archive_size = first_slice_size + (slice_number - 2)*sub_slice_size + last_slice_size;
 		else
-		    archive_size = 0; // unknown
+		    archive_size = first_slice_size + (slice_number - 2)*sub_slice_size + last_slice_size;
 	    }
 	    else // not reading from a sar
 	    {
